phoneengine/phonemodel/inc/cpemessagehandler.h
changeset 45 6b911d05207e
parent 37 ba76fc04e6c2
child 46 bc5a64e5bc3c
--- a/phoneengine/phonemodel/inc/cpemessagehandler.h	Fri Jun 04 10:19:18 2010 +0100
+++ b/phoneengine/phonemodel/inc/cpemessagehandler.h	Wed Jun 23 18:12:20 2010 +0300
@@ -28,7 +28,6 @@
 
 #include "mpecallhandling.h"
 #include "mpecallcontrolif.h" 
-#include "mpekeysequencerecognitionif.h"
 
 // CONSTANTS
 const TInt KModeNormal = 0;  // Normal System mode  
@@ -40,21 +39,6 @@
 _LIT( KPEValidDTMFChars, "0123456789*#pwPW" );
 _LIT( KPEValidDTMFStringStopChars, "+pPwW" );
 
-// DTMF Speed dial substitution
-_LIT( KPEValidSpeedDialChars, "23456789" );
-const TInt KPEDtmfSpeedDialSubstitutionsMax = 2; // prevent infinite loop.
-const TInt KPESpeedDialIndexMin = 2;
-const TInt KPESpeedDialIndexMax = 9;
-
-// DTMF parsing status for Speed dial location
-enum TPESpeedDialSubstituionStatus
-    {
-    EPEDtmfSpeedDialOk,
-    EPEDtmfSpeedDialPromptUser,
-    EPEDtmfSpeedDialNotAssigned,
-    EPEDtmfSpeedDialInvalidSpeedDial
-    };
-
 // Invalid characters in an dialing string, these chars can be removed from dial string
 _LIT( KPECharsThatCanBeDelete, "\"/ ().-" );
 
@@ -109,8 +93,7 @@
 NONSHARABLE_CLASS( CPEMessageHandler ) 
     : 
         public CBase, 
-        public MPECallControlIF,
-        public MPEKeySequenceRecognitionIF
+        public MPECallControlIF
     {
     public:  // Destructor
 
@@ -253,12 +236,6 @@
                                            const TBool aCheckForDelete ) const;
 
         /**
-        * Handles lifetimer data from customa api -> engineinfo.
-        * @return TInt possible error code..
-        */
-        TInt HandleGetLifeTimerData() const;
-
-        /**
         * Handles EPEMessageDTMFSent message from call handling subsystem
         * @param ECCPErrorNone or KPEDontSendMessage
         */
@@ -282,12 +259,6 @@
         * @return error code.
         */
         static TInt CallBackHandleSendDtmf( TAny* aAny );
-
-        /**
-        * Handles plus (+) sign in a DTMF string.
-        * @param aDtmfString Current DTMF string to process.
-        */
-        void HandlePlusSignInDtmf( const TPEDtmfString& aDtmfString );
         
         /**
         * Called asyncronously from callback.
@@ -510,10 +481,11 @@
         TInt HandleServiceEnabled();
         
         /**
          * Handles remote party information changed         
          * @since Series60_5.2         
          */
-        void HandleRemotePartyInfoChanged( );
+        void HandleRemotePartyInfoChanged( const TInt aCallId );
 
         /**
         * Handles swap message from the phone application 
@@ -604,12 +576,6 @@
         TInt HandleDialServiceCall(
             const TBool aClientCall );
     
-    public: // from MPEKeySequenceRecognitionIF
-        /**
-         * Executes provided key sequence if recognized.
-         */ 
-        TBool ExecuteKeySequenceL(const TDesC16 &aSequence);
-    
     private: // New functions
         
         /**
@@ -774,7 +740,12 @@
         * @param aClientCall, Informs is the current call client originated or not.
         * @return Return possible error code.
         */
-        TInt HandleDialCallL( const TBool aClientCall );      
+        TInt HandleDialCallL( const TBool aClientCall );
+
+        /**
+        * Reset CCCECallParameters to prevent of use a previous callīs parameters
+        */
+        void ResetClientCallData();
 
         /**
         * Checks if there are any connected video calls
@@ -510,10 +481,11 @@
         
         /**
-         * Handles remote party information changed         
+         * Handles remote party information changed   
+         * @param aCallId is the identification number of the call.               
          * @since Series60_5.2         
          */